Enum syntex_syntax::feature_gate::AttributeType
[−]
[src]
pub enum AttributeType {
Normal,
Whitelisted,
CrateLevel,
}Variants
NormalNormal, builtin attribute that is consumed by the compiler before the unused_attribute check
WhitelistedBuiltin attribute that may not be consumed by the compiler before the unused_attribute check. These attributes will be ignored by the unused_attribute lint
CrateLevelBuiltin attribute that is only allowed at the crate level